This is the mail archive of the java-patches@gcc.gnu.org mailing list for the Java project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[ecj] Patch: FYI: fix Serialization test


I'm checking this in on gcj-eclipse-merge-branch.

This fixes the failing Serialization test.

Tom

Index: ChangeLog
from  Tom Tromey  <tromey@redhat.com>
	* sources.am, Makefile.in: Rebuilt.
	* java/io/natObjectInputStream.cc (allocateObject): Now method on
	VMObjectStream.
	(currentLoader): Removed.
	* java/io/ObjectInputStream.java: Removed.
	* java/io/VMObjectInputStream.java: New file.
	* scripts/classes.pl (scan): Ignore .svn directories.
	* gcj/javaprims.h: Updated.

Index: scripts/classes.pl
===================================================================
--- scripts/classes.pl	(revision 120082)
+++ scripts/classes.pl	(working copy)
@@ -1,7 +1,7 @@
 # classes.pl - A perl program to generate most of the contents of
 # javaprims.h automatically.
 
-# Copyright (C) 1998, 1999, 2000, 2002, 2005  Free Software Foundation
+# Copyright (C) 1998, 1999, 2000, 2002, 2005, 2006  Free Software Foundation
 #
 # This file is part of libgcj.
 #
@@ -44,6 +44,7 @@
 	while (defined ($name = $d->read))
 	{
 	    next if $name eq 'CVS';
+	    next if $name eq '.svn';
 	    next if $name eq '.';
 	    next if $name eq '..';
 	    if ($dir eq 'java'
Index: java/io/VMObjectInputStream.java
===================================================================
--- java/io/VMObjectInputStream.java	(revision 0)
+++ java/io/VMObjectInputStream.java	(revision 0)
@@ -0,0 +1,56 @@
+/* ObjectInputStream.java -- Class used to read serialized objects
+   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2005
+   Free Software Foundation, Inc.
+
+This file is part of GNU Classpath.
+
+GNU Classpath is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+GNU Classpath is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GNU Classpath; see the file COPYING.  If not, write to the
+Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+02110-1301 USA.
+
+Linking this library statically or dynamically with other modules is
+making a combined work based on this library.  Thus, the terms and
+conditions of the GNU General Public License cover the whole
+combination.
+
+As a special exception, the copyright holders of this library give you
+permission to link this library with independent modules to produce an
+executable, regardless of the license terms of these independent
+modules, and to copy and distribute the resulting executable under
+terms of your choice, provided that you also meet, for each linked
+independent module, the terms and conditions of the license of that
+module.  An independent module is a module which is not derived from
+or based on this library.  If you modify this library, you may extend
+this exception to your version of the library, but you are not
+obligated to do so.  If you do not wish to do so, delete this
+exception statement from your version. */
+
+
+package java.io;
+
+import gnu.classpath.Configuration;
+import java.lang.reflect.Constructor;
+
+final class VMObjectInputStream
+{
+  /**
+   * Allocates a new Object of type clazz but without running the
+   * default constructor on it. It then calls the given constructor on
+   * it. The given constructor method comes from the constr_clazz
+   * which is a super class of the given clazz.
+   */
+  static native Object allocateObject(Class clazz, Class constr_clazz,
+				      Constructor constructor)
+    throws InstantiationException;
+}
Index: java/io/natObjectInputStream.cc
===================================================================
--- java/io/natObjectInputStream.cc	(revision 120082)
+++ java/io/natObjectInputStream.cc	(working copy)
@@ -1,6 +1,6 @@
 // natObjectInputStream.cc - Native part of ObjectInputStream class.
 
-/* Copyright (C) 1998, 1999, 2000, 2001, 2005  Free Software Foundation
+/* Copyright (C) 1998, 1999, 2000, 2001, 2005, 2006  Free Software Foundation
 
    This ObjectInputStream is part of libgcj.
 
@@ -14,8 +14,7 @@
 #include <jvm.h>
 #include <gcj/method.h>
 
-#include <java/io/ObjectInputStream$GetField.h>
-#include <java/io/ObjectInputStream.h>
+#include <java/io/VMObjectInputStream.h>
 #include <java/io/IOException.h>
 #include <java/lang/Class.h>
 #include <java/lang/reflect/Modifier.h>
@@ -32,7 +31,7 @@
 #endif
 
 jobject
-java::io::ObjectInputStream::allocateObject (jclass klass, jclass,
+java::io::VMObjectInputStream::allocateObject (jclass klass, jclass,
   ::java::lang::reflect::Constructor *ctr)
 {
   jobject obj = NULL;
@@ -69,12 +68,3 @@
 
   return obj;
 }
-
-java::lang::ClassLoader *
-java::io::ObjectInputStream::currentLoader ()
-{
-  jclass caller = _Jv_StackTrace::GetCallingClass (&ObjectInputStream::class$);
-  if (caller)
-    return caller->getClassLoaderInternal();
-  return NULL;
-}
@@ -1,6 +1,6 @@
-// natObjectInputStream.cc - Native part of ObjectInputStream class.
+// natObjectInputStream.cc - Native part of VMObjectInputStream class.
 


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]